@@ -26,28 +26,28 @@
     pred <- dplyr::mutate(pred, weights = weights)
   }
   if (mode == "regression") {
-    metrics <- pred %>%
-      yardstick::rmse(.data$truth, .data$prediction, case_weights = .data$weights) %>%
+    metrics <- pred |>
+      yardstick::rmse(.data$truth, .data$prediction, case_weights = .data$weights) |>
       dplyr::mutate(metric = .data$.estimate^2)
   } else {
     is_multinomial <- "class" %in% colnames(pred)
     if (is_multinomial) {
       level_names <- levels(pred$truth)
-      metrics <- pred %>%
-        dplyr::mutate(row_n = dplyr::row_number()) %>%
-        tidyr::spread(.data$class, .data$prediction) %>%
-        yardstick::mn_log_loss(truth = .data$truth, any_of(level_names), case_weights = .data$weights) %>%
+      metrics <- pred |>
+        dplyr::mutate(row_n = dplyr::row_number()) |>
+        tidyr::spread(.data$class, .data$prediction) |>
+        yardstick::mn_log_loss(truth = .data$truth, any_of(level_names), case_weights = .data$weights) |>
         dplyr::mutate(metric = .data$.estimate)
     } else {
-      metrics <- pred %>%
+      metrics <- pred |>
         yardstick::mn_log_loss(.data$truth, .data$prediction,
                                case_weights = .data$weights,
-                               event_level = "second") %>%
+                               event_level = "second") |>
         dplyr::mutate(metric = .data$.estimate)
     }
   }
 
-  metrics <- metrics %>%
+  metrics <- metrics |>
     dplyr::select(-".metric", -".estimator", -".estimate")
 
   return(metrics)
