@@ -8,7 +8,7 @@
   cv <- row$data$cv
   mask <- row$data$mask
 
-  data <- data %>%
+  data <- data |>
     dplyr::select(-!!mask)
 
   # Fit on full sample
@@ -34,9 +34,9 @@
       )
 
       # Define train and test data for slice
-      df_train <- rsample::training(splits) %>%
+      df_train <- rsample::training(splits) |>
         dplyr::select(-!!mask)
-      df_test <- rsample::testing(splits) %>%
+      df_test <- rsample::testing(splits) |>
         dplyr::select(-!!mask)
       train_samples <- splits$in_id
       test_samples <- rsample::complement(splits)
@@ -45,22 +45,22 @@
       res_row$model_object[[1]]$set_args(weights = wts[train_samples])
       res_row$model_object[[1]]$fit(df_train)
 
-      res_row <- res_row %>%
+      res_row <- res_row |>
         dplyr::mutate(slice_id = id)
 
       # Store test data
       if (nrow(df_test) > 0) {
-        res_row <- res_row %>%
+        res_row <- res_row |>
           dplyr::bind_cols(tidyr::nest(df_test, df_test = everything()))
       } else {
-        res_row <- res_row %>%
+        res_row <- res_row |>
           dplyr::mutate(df_test = NULL)
       }
 
       # Store weights
       if (!is.null(wts)) {
         test_weights <- tibble(weights = wts[test_samples])
-        res_row <- res_row %>%
+        res_row <- res_row |>
           dplyr::bind_cols(tidyr::nest(test_weights, weights = everything()))
       }
 
@@ -72,8 +72,8 @@
     if (!row$return_grid & row$model_object$has_predict_method) {
 
       # Out-of-sample predictions
-      pred <- cv_res %>%
-        purrr::transpose() %>%
+      pred <- cv_res |>
+        purrr::transpose() |>
         purrr::map_dfr(function(row) {
           if (is.null(row$df_test) | is.null(row$model_object$object))
             return(NULL)
@@ -81,11 +81,11 @@
           if (is.null(out))
             return(NULL)
           if (!"grid_id" %in% colnames(out)) {
-            out <- out %>%
+            out <- out |>
               dplyr::mutate(grid_id = row[["grid_id"]])
           }
-          out <- out %>%
-            dplyr::group_by(.data$grid_id) %>%
+          out <- out |>
+            dplyr::group_by(.data$grid_id) |>
             dplyr::mutate(weights = row$weights$weights)
           return(out)
         })
@@ -95,11 +95,11 @@
     }
 
     # Unnest hyperparameters and join metrics
-    cv_res <- cv_res %>%
-      dplyr::select(-any_of(c("weights", "df_test"))) %>%
-      dplyr::group_nest(dplyr::row_number()) %>%
-      dplyr::pull(.data$data) %>%
-      purrr::map_dfr(.unnest_args, model_args) %>%
+    cv_res <- cv_res |>
+      dplyr::select(-any_of(c("weights", "df_test"))) |>
+      dplyr::group_nest(dplyr::row_number()) |>
+      dplyr::pull(.data$data) |>
+      purrr::map_dfr(.unnest_args, model_args) |>
       dplyr::left_join(metrics, by = c("grid_id"))
 
   } else {
@@ -107,11 +107,11 @@
   }
 
   out_row <- .unnest_args(out_row)
-  out_row <- out_row %>%
+  out_row <- out_row |>
     dplyr::mutate(slice_id = "FULL")
   # Ensure identical grids as in CV (can differ if some slices have errors)
   if (!is.null(cv_res)) {
-    cv_res <- cv_res %>%
+    cv_res <- cv_res |>
       dplyr::filter(.data$grid_id %in% out_row$grid_id)
     result <- dplyr::bind_rows(out_row, cv_res)
   } else {
