@@ -27,20 +27,21 @@ fitted.tidyfit.models <- function(object, ...) {
   .weights <- attr(object, "structure")$weights
 
   object <- .warn_and_remove_errors(object)
+  object <- .nest_settings(object)
 
   sel_cols <- c("settings", "estimator_fct", "size (MB)", "errors", "warnings", "messages")
-  out <- object %>%
-    dplyr::select(-dplyr::any_of(sel_cols)) %>%
-    dplyr::mutate(fitted = purrr::map(.data$model_object, ~.$fitted())) %>%
-    dplyr::select(- "model_object") %>%
+  out <- object |>
+    dplyr::select(-dplyr::any_of(sel_cols)) |>
+    dplyr::mutate(fitted = purrr::map(.data$model_object, ~.$fitted())) |>
+    dplyr::select(- "model_object") |>
     tidyr::unnest("fitted")
 
   col_ord <- c(gr_vars, "model", "grid_id", "slice_id", "class", "fitted")
-  out <- out %>%
+  out <- out |>
     dplyr::relocate(any_of(col_ord))
 
-  out <- out %>%
-    dplyr::group_by(across(any_of(c(gr_vars, "model")))) %>%
+  out <- out |>
+    dplyr::group_by(across(any_of(c(gr_vars, "model")))) |>
     dplyr::mutate(nids = length(unique(.data$grid_id)))
 
   if (all(out$nids==1)) {
