@@ -156,7 +156,7 @@ m <- function(
     purrr::map_dfr(.unnest_args) |>
     dplyr::select(-"r")
   col_ord <- c("estimator_fct", "size (MB)", "grid_id", "model_object", "settings", "errors", "warnings", "messages")
-  mods <- dplyr::relocate(mods, any_of(col_ord)) %>%
+  mods <- dplyr::relocate(mods, any_of(col_ord)) |>
     dplyr::arrange(.data$grid_id)
   mods <- tibble::new_tibble(mods, class = "tidyfit.models")
   return(mods)
