@@ -45,7 +45,7 @@ model_definition <- R6::R6Class(
     },
     predict = function(data, check_cols = TRUE, ...) {
       if (!self$has_predict_method) {
-        warning(paste0("No prediction method for type '", self$method, "'."))
+        warning(paste0("No prediction method for type '", self$method, "'."), call. = FALSE)
         return(NULL)
       }
       all_args <- list(object = self$object,
@@ -56,12 +56,12 @@ model_definition <- R6::R6Class(
     },
     coef = function(...) {
       if (!.check_method(self$method, "has_coef_method")) {
-        warning(paste0("No coef method for type '", self$method, "'. Try using 'explain()'"))
+        warning(paste0("No coef method for type '", self$method, "'. Try using 'explain()'"), call. = FALSE)
         return(tibble(term=character(), estimate=numeric()))
       }
       all_args <- list(object = self$object, self = self)
       coef_df <- do.call(.coef, all_args)
-      coef_df <- coef_df %>%
+      coef_df <- coef_df |>
         dplyr::mutate(term = dplyr::if_else(.data$term %in% names(self$names_map), self$names_map[.data$term], .data$term))
       return(coef_df)
     },
@@ -75,14 +75,14 @@ model_definition <- R6::R6Class(
     },
     explain = function(use_package, use_method, additional_args) {
       if (!.check_method(self$method, "has_importance_method")) {
-        warning(paste0("No explain method for type '", self$method, "'."))
+        warning(paste0("No explain method for type '", self$method, "'."), call. = FALSE)
         return(dplyr::tibble(term = character(), importance = double()))
       }
       all_args <- list(object = self$object, self = self, use_package = use_package, use_method = use_method)
       all_args <- append(all_args, additional_args)
       var_imp_df <- do.call(.explain, all_args)
       if (nrow(var_imp_df) > 0) {
-        var_imp_df <- var_imp_df %>%
+        var_imp_df <- var_imp_df |>
           dplyr::mutate(term = dplyr::if_else(.data$term %in% names(self$names_map), self$names_map[.data$term], .data$term))
       }
 
@@ -94,7 +94,7 @@ model_definition <- R6::R6Class(
           crayon::italic("mode:"), crayon::bold(self$mode), "|",
           crayon::italic("fitted:"), crayon::bold(ifelse(is.null(self$object), "no", "yes")), "\n",
           ifelse(is.null(self$error), crayon::green("no errors \u2714"), crayon::red("check errors \u2716")), "|",
-          ifelse(is.null(self$warnings), crayon::green("no warnings \u2714"), crayon::yellow("check warnings \u2716")))
+          ifelse(is.null(self$warnings), crayon::green("no warnings \u2714"), crayon::yellow("check warnings \u2716")), "\n")
     },
     set_args = function(..., overwrite = TRUE) {
       new_args <- lapply(list(...), unlist)
@@ -124,6 +124,9 @@ model_definition <- R6::R6Class(
         stop("data is not set yet")
       }
     },
+    get_syntactic_response_var_name = function(...) {
+      return(all.vars(self$formula)[1])
+    },
     clear = function(...) {
       self$object = NULL
       self$error = NULL
@@ -145,6 +148,7 @@ model_definition <- R6::R6Class(
   self$error <- model$error[[1]]
   if (length(model$result$messages)>0) self$messages <- paste(model$result$messages, collapse = " | ")
   if (length(model$result$warnings)>0) self$warnings <- paste(model$result$warnings, collapse = " | ")
+  self$estimator <- METHOD_REGISTER[[self$method]]$estimator
   invisible(self)
 }
 
@@ -152,10 +156,14 @@ model_definition <- R6::R6Class(
   # keep only valid columns
   data_non_na <- dplyr::select(data, dplyr::any_of(self$get_valid_data_columns()))
 
+  # stop if target is not in valid data columns
+  if (!self$get_syntactic_response_var_name() %in% self$get_valid_data_columns())
+    stop("NA or Inf values found in the target column.", call. = FALSE)
+
   # stop if there are NA values in data
   na_columns <- colnames(data_non_na)[apply(data_non_na, 2, function(x) any(is.na(x)))]
   if (length(na_columns) > 0)
-    stop(paste("NA or Inf values found in data. columns:", paste(na_columns, collapse = "; ")))
+    stop(paste("NA or Inf values found in data. columns:", paste(na_columns, collapse = "; ")), call. = FALSE)
 
   # fix non-syntactic names in data
   prepared_data <- data_non_na
